.. _contents:

Chiplotle  |release|  documentation
=====================================


.. toctree::
   :maxdepth: 1

   chapters/about/index
   install
   chapters/configuration/index

.. toctree::
   :maxdepth: 1

   chapters/tutorial/index
   chapters/plotters/index
   chapters/hardware/index
   chapters/fundamentals/index
   chapters/faq/index
   chapters/mailinglist/index

.. toctree::
   :maxdepth: 1

   chapters/api/index
   chapters/contributors/index

.. toctree::
   :maxdepth: 1

   chapters/resources/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

